summaryrefslogtreecommitdiffstats
path: root/kttsd/plugins/command/commandconf.h
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/plugins/command/commandconf.h')
-rw-r--r--kttsd/plugins/command/commandconf.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/kttsd/plugins/command/commandconf.h b/kttsd/plugins/command/commandconf.h
index 7e9a573..b3889b9 100644
--- a/kttsd/plugins/command/commandconf.h
+++ b/kttsd/plugins/command/commandconf.h
@@ -19,8 +19,8 @@
#define _COMMANDCONF_H_
// Qt includes.
-#include <qstring.h>
-#include <qstringlist.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
// KDE includes.
#include <kconfig.h>
@@ -39,7 +39,7 @@ class CommandConf : public PlugInConf {
public:
/** Constructor */
- CommandConf( QWidget* parent = 0, const char* name = 0, const QStringList &args = QStringList());
+ CommandConf( TQWidget* parent = 0, const char* name = 0, const TQStringList &args = TQStringList());
/** Destructor */
~CommandConf();
@@ -51,14 +51,14 @@ class CommandConf : public PlugInConf {
* valid settings. NOTE that this is not called after the modules is loaded,
* so you probably want to call this method in the constructor.
*/
- void load(KConfig *config, const QString &configGroup);
+ void load(KConfig *config, const TQString &configGroup);
/** This function gets called when the user wants to save the settings in
* the user interface, updating the config files or wherever the
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok".
*/
- void save(KConfig *config, const QString &configGroup);
+ void save(KConfig *config, const TQString &configGroup);
/** This function is called to set the settings in the module to sensible
* default values. It gets called when hitting the "Default" button. The
@@ -71,7 +71,7 @@ class CommandConf : public PlugInConf {
* This function informs the plugin of the desired language to be spoken
* by the plugin. The plugin should attempt to adapt itself to the
* specified language code, choosing sensible defaults if necessary.
* If the passed-in code is QString::null, no specific language has
* been chosen.
* @param lang The desired language code or Null if none.
*
@@ -83,16 +83,16 @@ class CommandConf : public PlugInConf {
* not the given country, treat it as though the country
* code were not specified, i.e., adapt to the given language.
*/
- void setDesiredLanguage(const QString &lang);
+ void setDesiredLanguage(const TQString &lang);
/**
* Return fully-specified talker code for the configured plugin. This code
* uniquely identifies the configured instance of the plugin and distinquishes
* one instance from another. If the plugin has not been fully configured,
* i.e., cannot yet synthesize, return QString::null.
* @return Fully-specified talker code.
*/
- QString getTalkerCode();
+ TQString getTalkerCode();
private slots:
void configChanged(){
@@ -104,7 +104,7 @@ class CommandConf : public PlugInConf {
void slotSynthStopped();
private:
- QString m_languageCode;
+ TQString m_languageCode;
// Configuration Widget.
CommandConfWidget* m_widget;
@@ -112,10 +112,10 @@ class CommandConf : public PlugInConf {
// Command synthesizer.
CommandProc* m_commandProc;
// Synthesized wave file name.
- QString m_waveFile;
+ TQString m_waveFile;
// Progress dialog.
KProgressDialog* m_progressDlg;
// Codec list.
- QStringList m_codecList;
+ TQStringList m_codecList;
};
#endif // _COMMANDCONF_H_
@@ -71,7 +71,7 @@ class CommandConf : public PlugInConf {
* by the plugin. The plugin should attempt to adapt itself to the
* specified language code, choosing sensible defaults if necessary.
- * If the passed-in code is QString::null, no specific language has
+ * If the passed-in code is TQString::null, no specific language has
* been chosen.
* @param lang The desired language code or Null if none.
@@ -83,16 +83,16 @@ class CommandConf : public PlugInConf {
* uniquely identifies the configured instance of the plugin and distinquishes
* one instance from another. If the plugin has not been fully configured,
- * i.e., cannot yet synthesize, return QString::null.
+ * i.e., cannot yet synthesize, return TQString::null.
* @return Fully-specified talker code.
*/